@@ -26,7 +26,6 @@
 #include "util.h"
 #include "group-private.h"
 #include "group-props.h"
-#include "window-private.h"
 #include "window.h"
 
 static MetaGroup*
@@ -273,13 +272,3 @@ meta_group_property_notify (MetaGroup  *group,
   return TRUE;
 
 }
-
-int
-meta_group_get_size (MetaGroup *group)
-{
-  if (!group)
-    return 0;
-
-  return group->refcount;
-}
-
