@@ -363,11 +363,11 @@ meta_finalize (void)
 {
   MetaDisplay *display = meta_get_display();
 
-  meta_session_shutdown ();
-
   if (display)
     meta_display_close (display,
                         CurrentTime); /* I doubt correct timestamps matter here */
+
+  meta_session_shutdown ();
 }
 
 static int sigterm_pipe_fds[2] = { -1, -1 };
@@ -377,9 +377,8 @@ sigterm_handler (int signum)
 {
   if (sigterm_pipe_fds[1] >= 0)
     {
-      int dummy;
-
-      dummy = write (sigterm_pipe_fds[1], "", 1);
+      if ( write (sigterm_pipe_fds[1], "", 1) == -1 )
+        g_printerr ("metacity: write to sigterm_pipe failed.\n");
       close (sigterm_pipe_fds[1]);
       sigterm_pipe_fds[1] = -1;
     }
